pub struct ARImageProcInfo {
pub image_x: i32,
pub image_y: i32,
pub image2: Option<Vec<u8>>,
pub image_temp_u16: Option<Vec<u16>>,
pub hist_bins: [u32; 256],
pub cdf_bins: [u32; 256],
pub min: u8,
pub max: u8,
}Expand description
Structure holding settings for an instance of the image-processing pipeline
Fields
image_x: i32Width of image buffer
image_y: i32Height of image buffer
image2: Option<Vec<u8>>Extra buffer, allocated as required for filtering
image_temp_u16: Option<Vec<u16>>Intermediate buffer for separable filters
hist_bins: [u32; 256]Luminance histogram
cdf_bins: [u32; 256]Luminance cumulative density function
min: u8Minimum luminance
max: u8Maximum luminance
Implementations
Sourceimpl ARImageProcInfo
impl ARImageProcInfo
Sourcepub fn luma_hist(&mut self, data: &[u8]) -> Result<(), &'static str>
pub fn luma_hist(&mut self, data: &[u8]) -> Result<(), &'static str>
Calculate luminance histogram
Sourcepub fn luma_hist_and_cdf(&mut self, data: &[u8]) -> Result<(), &'static str>
pub fn luma_hist_and_cdf(&mut self, data: &[u8]) -> Result<(), &'static str>
Calculate image histogram and cumulative density function
Sourcepub fn luma_hist_and_cdf_and_percentile(
&mut self,
data: &[u8],
percentile: f32,
) -> Result<u8, &'static str>
pub fn luma_hist_and_cdf_and_percentile( &mut self, data: &[u8], percentile: f32, ) -> Result<u8, &'static str>
Calculate image histogram, cumulative density function, and luminance value at a given histogram percentile
Sourcepub fn luma_hist_and_cdf_and_median(
&mut self,
data: &[u8],
) -> Result<u8, &'static str>
pub fn luma_hist_and_cdf_and_median( &mut self, data: &[u8], ) -> Result<u8, &'static str>
Calculate image histogram, cumulative density function, and median luminance value
Sourcepub fn luma_hist_and_otsu(&mut self, data: &[u8]) -> Result<u8, &'static str>
pub fn luma_hist_and_otsu(&mut self, data: &[u8]) -> Result<u8, &'static str>
Calculate image histogram, and binarize image using Otsu’s method