Module marker

Module marker 

Marker Detection Pipeline Ported from arDetectMarker.c, arDetectMarker2.c, and arGetMarkerInfo.c

Enums

ImageProcMode

Constants

AR_AREA_MAX
AR_AREA_MIN
AR_CHAIN_MAX
AR_SQUARE_FIT_THRESH
AR_SQUARE_MAX

Functions

ar_detect_marker
High-level AR marker detection pipeline.
ar_detect_marker2
Refine labeled regions into square (marker) candidates.
ar_get_line
Fits undistorted straight lines to each of the four sides of a detected square.
ar_get_marker_info
Resolves each square candidate into a fully identified marker.