Module pattern

Module pattern 

Pattern Template matching logic Ported natively to safe Rust from arPattLoad.c and arPattGetID.c

Constants

AR_PATT_CONTRAST_THRESH1
AR_PATT_NUM_MAX
AR_PATT_SIZE1
AR_TEMPLATE_MATCHING_COLOR
AR_TEMPLATE_MATCHING_MONO

Functions

ar_patt_get_image
ar_patt_load
Loads a pattern from a specified file path.
ar_patt_load_from_buffer
Loads a pattern into the provided ARPattHandle from a text-based buffer. Returns the index of the loaded pattern.
dot_product_scalar
get_cpara
pattern_match
Matches the unwarped square marker against loaded templates via NCC (Normalized Cross Correlation).