Module types

Module types 

Core Data Structures for WebARKitLib Translated from ARToolKit C headers (ar.h, param.h, etc.)

Re-exports

pub use crate::icp::ICPHandleT;
pub use crate::icp::ICPStereoHandleT;

Structs

AR2VideoBufferT
A structure which carries information about a video frame retrieved by the video library.
AR2VideoTimestampT
A structure to hold a timestamp in seconds and microseconds, with arbitrary epoch.
AR3DHandle
Structure holding state of an instance of the monocular pose estimator.
AR3DStereoHandle
Structure holding state of an instance of the stereo pose estimator.
ARHandle
Structure holding state of an instance of the square marker tracker.
ARImageProcInfo
ARLabelInfo
ARMarkerInfo
Describes a detected trapezoidal area (a candidate for a marker match).
ARMarkerInfo2
Captures detail of a trapezoidal region which is a candidate for marker detection.
ARParam
Structure holding camera parameters, including image size, projection matrix and lens distortion parameters.
ARParamLT
ARParamLTf
ARPattHandle
ARTrackingHistory

Enums

ARLabelingThreshMode
ARMarkerInfoCutoffPhase
Result codes returned by arDetectMarker to report state of individual detected trapezoidal regions.
ARMatrixCodeType
ARPixelFormat

Constants

AR_CHAIN_MAX
AR_DIST_FACTOR_NUM_MAX
AR_LABELING_WORK_SIZE
AR_MATRIX_CODE_DETECTION
AR_SQUARE_MAX
AR_TEMPLATE_MATCHING_COLOR
AR_TEMPLATE_MATCHING_COLOR_AND_MATRIX_CODE_DETECTION
AR_TEMPLATE_MATCHING_MONO
AR_TEMPLATE_MATCHING_MONO_AND_MATRIX_CODE_DETECTION

Type Aliases

ARLabelingLabelType
ARdouble