AR2VideoBufferT

Struct AR2VideoBufferT 

pub struct AR2VideoBufferT {
    pub buff: Option<Vec<u8>>,
    pub buf_planes: Option<Vec<Vec<u8>>>,
    pub buf_plane_count: u32,
    pub buff_luma: Option<Vec<u8>>,
    pub fill_flag: bool,
    pub time: AR2VideoTimestampT,
}
A structure which carries information about a video frame retrieved by the video library.

Fields

buff: Option<Vec<u8>>

A pointer to the packed video data for this video frame. In Rust, we use a slice or Vec depending on ownership, usually represented as a raw slice or Vec.

buf_planes: Option<Vec<Vec<u8>>>

For multi-planar video frames, arrays of planes.

buf_plane_count: u32

Number of planes.

buff_luma: Option<Vec<u8>>

Luminance-only version of the image.

fill_flag: bool

Set to true when buff is valid.

time: AR2VideoTimestampT

Time at which the buffer was filled.