#[repr(C)]pub struct ARParam {
pub xsize: i32,
pub ysize: i32,
pub mat: [[ARdouble; 4]; 3],
pub dist_factor: [ARdouble; 9],
pub dist_function_version: i32,
}Expand description
Structure holding camera parameters, including image size, projection matrix and lens distortion parameters.
Fields
xsize: i32The width in pixels of images returned by the video library for the camera.
ysize: i32The height in pixels of images returned by the video library for the camera.
mat: [[ARdouble; 4]; 3]The projection matrix for the calibrated camera parameters.
dist_factor: [ARdouble; 9]Distortion factors.
dist_function_version: i32Distortion function version.
Implementations