Marker Detection Pipeline Ported from arDetectMarker.c, arDetectMarker2.c, and arGetMarkerInfo.c
Enums
Constants
Functions
- ar_
detect_ marker - High-level AR marker detection pipeline.
- ar_
detect_ marker2 - Refine labeled regions into square (marker) candidates.
- ar_
get_ line - Fits undistorted straight lines to each of the four sides of a detected square.
- ar_
get_ marker_ info - Resolves each square candidate into a fully identified marker.