Pattern Template matching logic Ported natively to safe Rust from arPattLoad.c and arPattGetID.c
Constants
- AR_
PATT_ CONTRAST_ THRES H1 - AR_
PATT_ NUM_ MAX - AR_
PATT_ SIZE1 - AR_
TEMPLATE_ MATCHING_ COLOR - AR_
TEMPLATE_ MATCHING_ MONO
Functions
- ar_
patt_ get_ image - ar_
patt_ load - Loads a pattern from a specified file path.
- ar_
patt_ load_ from_ buffer - Loads a pattern into the provided ARPattHandle from a text-based buffer. Returns the index of the loaded pattern.
- dot_
product_ scalar - get_
cpara - pattern_
match - Matches the unwarped square marker against loaded templates via NCC (Normalized Cross Correlation).