Core Data Structures for WebARKitLib Translated from ARToolKit C headers (ar.h, param.h, etc.)
Re-exports
pub use crate::icp::ICPHandleT;pub use crate::icp::ICPStereoHandleT;
Structs
- AR2Video
BufferT - A structure which carries information about a video frame retrieved by the video library.
- AR2Video
TimestampT - A structure to hold a timestamp in seconds and microseconds, with arbitrary epoch.
- AR3D
Handle - Structure holding state of an instance of the monocular pose estimator.
- AR3D
Stereo Handle - Structure holding state of an instance of the stereo pose estimator.
- ARHandle
- Structure holding state of an instance of the square marker tracker.
- ARImage
Proc Info - ARLabel
Info - ARMarker
Info - Describes a detected trapezoidal area (a candidate for a marker match).
- ARMarker
Info2 - Captures detail of a trapezoidal region which is a candidate for marker detection.
- ARParam
- Structure holding camera parameters, including image size, projection matrix and lens distortion parameters.
- ARParamLT
- ARParamL
Tf - ARPatt
Handle - ARTracking
History
Enums
- ARLabeling
Thresh Mode - ARMarker
Info Cutoff Phase - Result codes returned by arDetectMarker to report state of individual detected trapezoidal regions.
- ARMatrix
Code Type - ARPixel
Format
Constants
- AR_
CHAIN_ MAX - AR_
DIST_ FACTOR_ NUM_ MAX - AR_
LABELING_ WORK_ SIZE - AR_
MATRIX_ CODE_ DETECTION - AR_
SQUARE_ MAX - AR_
TEMPLATE_ MATCHING_ COLOR - AR_
TEMPLATE_ MATCHING_ COLOR_ AND_ MATRIX_ CODE_ DETECTION - AR_
TEMPLATE_ MATCHING_ MONO - AR_
TEMPLATE_ MATCHING_ MONO_ AND_ MATRIX_ CODE_ DETECTION