#[repr(C)]pub struct ARMarkerInfo {Show 17 fields
pub area: i32,
pub id: i32,
pub id_patt: i32,
pub id_matrix: i32,
pub dir: i32,
pub dir_patt: i32,
pub dir_matrix: i32,
pub cf: ARdouble,
pub cf_patt: ARdouble,
pub cf_matrix: ARdouble,
pub pos: [ARdouble; 2],
pub line: [[ARdouble; 3]; 4],
pub vertex: [[ARdouble; 2]; 4],
pub marker_info2_ptr: *mut ARMarkerInfo2,
pub cutoff_phase: ARMarkerInfoCutoffPhase,
pub error_corrected: i32,
pub global_id: u64,
}Expand description
Describes a detected trapezoidal area (a candidate for a marker match).
This serves as the primary output of marker detection. It contains both raw properties of the shape (area, pos) and, if successfully matched, the identified marker ID and viewing direction.
Fields
area: i32Area in pixels of the largest connected region.
id: i32Marker ID if valid, or -1 if invalid (global ID regardless of matching type).
id_patt: i32Template marker ID if matched via template matching, -1 otherwise.
id_matrix: i32Matrix (barcode) marker ID if matched via matrix code, -1 otherwise.
dir: i32Orientation of the marker (0, 1, 2, or 3) representing rotation in 90° increments.
dir_patt: i32Orientation if matched via template matching.
dir_matrix: i32Orientation if matched via matrix code.
cf: ARdoubleConfidence value of the match (0.0 to 1.0).
cf_patt: ARdoubleConfidence value from template matching.
cf_matrix: ARdoubleConfidence value from matrix code decoding.
pos: [ARdouble; 2]Center of the marker (2D coordinate).
line: [[ARdouble; 3]; 4]Line equations of the four sides of the marker in 2D space [a, b, c].
vertex: [[ARdouble; 2]; 4]2D coordinates of the four corners in ideal (undistorted) camera space.
marker_info2_ptr: *mut ARMarkerInfo2Pointer to source region info for this marker.
cutoff_phase: ARMarkerInfoCutoffPhaseTracking phase at which the marker was cut off
error_corrected: i32The numbers of errors detected and corrected
global_id: u64Global ID for matrix codes